export declare enum CacheListConcatenateBackResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheListConcatenateFrontResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheListPushBackResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheListPushFrontResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheListRemoveValueResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheListRetainResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheListFetchResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheListLengthResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheListPopBackResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheListPopFrontResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
