export declare class SigningKey {
    private readonly keyId;
    private readonly expiresAt;
    private readonly endpoint;
    constructor(keyId: string, expiresAt: Date, endpoint: string);
    getKeyId(): string;
    getExpiresAt(): Date;
    getEndpoint(): string;
}
