/**
 * This file exists as a layer between our javascript classes and the grpc generated
 * ones. Its required since the types generated by grpc-web are different than those
 * generated by grpc for node. Inside of the respective clients, we will map the grpc
 * response types to these corresponding types. This allows us to share the response
 * messages between the 2 sdks.
 */
export declare enum _ECacheResult {
    Invalid = 0,
    Ok = 1,
    Hit = 2,
    Miss = 3
}
export declare class _DictionaryFieldValuePair {
    readonly field: Uint8Array;
    readonly value: Uint8Array;
    constructor({ field, value }: {
        field: Uint8Array;
        value: Uint8Array;
    });
}
export declare class _DictionaryGetResponsePart {
    readonly result: _ECacheResult;
    readonly cacheBody: Uint8Array;
    constructor(result: _ECacheResult, cacheBody: Uint8Array);
}
export declare class _SortedSetGetScoreResponsePart {
    readonly result: _ECacheResult;
    readonly score: number;
    constructor(result: _ECacheResult, score: number);
}
export declare class _SigningKey {
    readonly key: string;
    readonly expiresAt: number;
    constructor(key?: string, expiresAt?: number);
}
export declare class _SortedSetElement {
    readonly value: Uint8Array;
    readonly score: number;
    constructor(value: Uint8Array, score: number);
}
export declare class _RankedElement {
    readonly id: number;
    readonly score: number;
    readonly rank: number;
    constructor(id: number, score: number, rank: number);
}
