export declare enum CacheDictionaryGetFieldsResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheDictionaryGetFieldResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheDictionaryFetchResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheDictionaryIncrementResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheDictionaryLengthResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheDictionaryRemoveFieldResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheDictionaryRemoveFieldsResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheDictionarySetFieldResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheDictionarySetFieldsResponse {
    Success = "Success",
    Error = "Error"
}
