export interface MomentoLogger {
    error(msg: string, ...args: unknown[]): void;
    warn(msg: string, ...args: unknown[]): void;
    info(msg: string, ...args: unknown[]): void;
    debug(msg: string, ...args: unknown[]): void;
    trace(msg: string, ...args: unknown[]): void;
}
export interface MomentoLoggerFactory {
    getLogger(loggerName: string | any): MomentoLogger;
}
