import { CacheSelector } from './permission-scope';
import { DisposableTokenScope } from './disposable-token-scope';
export * from './permission-scopes';
export declare function cacheKeyReadWrite(cacheSelector: CacheSelector, key: string): DisposableTokenScope;
export declare function cacheKeyPrefixReadWrite(cacheSelector: CacheSelector, keyPrefix: string): DisposableTokenScope;
export declare function cacheKeyReadOnly(cacheSelector: CacheSelector, key: string): DisposableTokenScope;
export declare function cacheKeyPrefixReadOnly(cacheSelector: CacheSelector, keyPrefix: string): DisposableTokenScope;
export declare function cacheKeyWriteOnly(cacheSelector: CacheSelector, key: string): DisposableTokenScope;
export declare function cacheKeyPrefixWriteOnly(cacheSelector: CacheSelector, keyPrefix: string): DisposableTokenScope;
