import { CacheSelector, FunctionSelector, PermissionScope, TopicSelector } from './permission-scope';
export declare function functionInvoke(cacheSelector: CacheSelector, functionSelector: FunctionSelector): PermissionScope;
export declare function functionPermitNone(cacheSelector: CacheSelector, functionSelector: FunctionSelector): PermissionScope;
export declare function cacheReadWrite(cacheSelector: CacheSelector): PermissionScope;
export declare function cacheReadOnly(cacheSelector: CacheSelector): PermissionScope;
export declare function cacheWriteOnly(cacheSelector: CacheSelector): PermissionScope;
export declare function topicSubscribeOnly(cacheSelector: CacheSelector, topicSelector: TopicSelector): PermissionScope;
export declare function topicPublishSubscribe(cacheSelector: CacheSelector, topicSelector: TopicSelector): PermissionScope;
export declare function topicPublishOnly(cacheSelector: CacheSelector, topicSelector: TopicSelector): PermissionScope;
