"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CacheSortedSetUnionStoreResponse = exports.CacheSortedSetRemoveElementsResponse = exports.CacheSortedSetRemoveElementResponse = exports.CacheSortedSetPutElementsResponse = exports.CacheSortedSetPutElementResponse = exports.CacheSortedSetLengthByScoreResponse = exports.CacheSortedSetLengthResponse = exports.CacheSortedSetIncrementScoreResponse = exports.CacheSortedSetGetScoresResponse = exports.CacheSortedSetGetScoreResponse = exports.CacheSortedSetGetRankResponse = exports.CacheSortedSetFetchResponse = void 0;
var CacheSortedSetFetchResponse;
(function (CacheSortedSetFetchResponse) {
    CacheSortedSetFetchResponse["Hit"] = "Hit";
    CacheSortedSetFetchResponse["Miss"] = "Miss";
    CacheSortedSetFetchResponse["Error"] = "Error";
})(CacheSortedSetFetchResponse = exports.CacheSortedSetFetchResponse || (exports.CacheSortedSetFetchResponse = {}));
var CacheSortedSetGetRankResponse;
(function (CacheSortedSetGetRankResponse) {
    CacheSortedSetGetRankResponse["Hit"] = "Hit";
    CacheSortedSetGetRankResponse["Miss"] = "Miss";
    CacheSortedSetGetRankResponse["Error"] = "Error";
})(CacheSortedSetGetRankResponse = exports.CacheSortedSetGetRankResponse || (exports.CacheSortedSetGetRankResponse = {}));
var CacheSortedSetGetScoreResponse;
(function (CacheSortedSetGetScoreResponse) {
    CacheSortedSetGetScoreResponse["Hit"] = "Hit";
    CacheSortedSetGetScoreResponse["Miss"] = "Miss";
    CacheSortedSetGetScoreResponse["Error"] = "Error";
})(CacheSortedSetGetScoreResponse = exports.CacheSortedSetGetScoreResponse || (exports.CacheSortedSetGetScoreResponse = {}));
var CacheSortedSetGetScoresResponse;
(function (CacheSortedSetGetScoresResponse) {
    CacheSortedSetGetScoresResponse["Hit"] = "Hit";
    CacheSortedSetGetScoresResponse["Miss"] = "Miss";
    CacheSortedSetGetScoresResponse["Error"] = "Error";
})(CacheSortedSetGetScoresResponse = exports.CacheSortedSetGetScoresResponse || (exports.CacheSortedSetGetScoresResponse = {}));
var CacheSortedSetIncrementScoreResponse;
(function (CacheSortedSetIncrementScoreResponse) {
    CacheSortedSetIncrementScoreResponse["Success"] = "Success";
    CacheSortedSetIncrementScoreResponse["Error"] = "Error";
})(CacheSortedSetIncrementScoreResponse = exports.CacheSortedSetIncrementScoreResponse || (exports.CacheSortedSetIncrementScoreResponse = {}));
var CacheSortedSetLengthResponse;
(function (CacheSortedSetLengthResponse) {
    CacheSortedSetLengthResponse["Hit"] = "Hit";
    CacheSortedSetLengthResponse["Miss"] = "Miss";
    CacheSortedSetLengthResponse["Error"] = "Error";
})(CacheSortedSetLengthResponse = exports.CacheSortedSetLengthResponse || (exports.CacheSortedSetLengthResponse = {}));
var CacheSortedSetLengthByScoreResponse;
(function (CacheSortedSetLengthByScoreResponse) {
    CacheSortedSetLengthByScoreResponse["Hit"] = "Hit";
    CacheSortedSetLengthByScoreResponse["Miss"] = "Miss";
    CacheSortedSetLengthByScoreResponse["Error"] = "Error";
})(CacheSortedSetLengthByScoreResponse = exports.CacheSortedSetLengthByScoreResponse || (exports.CacheSortedSetLengthByScoreResponse = {}));
var CacheSortedSetPutElementResponse;
(function (CacheSortedSetPutElementResponse) {
    CacheSortedSetPutElementResponse["Success"] = "Success";
    CacheSortedSetPutElementResponse["Error"] = "Error";
})(CacheSortedSetPutElementResponse = exports.CacheSortedSetPutElementResponse || (exports.CacheSortedSetPutElementResponse = {}));
var CacheSortedSetPutElementsResponse;
(function (CacheSortedSetPutElementsResponse) {
    CacheSortedSetPutElementsResponse["Success"] = "Success";
    CacheSortedSetPutElementsResponse["Error"] = "Error";
})(CacheSortedSetPutElementsResponse = exports.CacheSortedSetPutElementsResponse || (exports.CacheSortedSetPutElementsResponse = {}));
var CacheSortedSetRemoveElementResponse;
(function (CacheSortedSetRemoveElementResponse) {
    CacheSortedSetRemoveElementResponse["Success"] = "Success";
    CacheSortedSetRemoveElementResponse["Error"] = "Error";
})(CacheSortedSetRemoveElementResponse = exports.CacheSortedSetRemoveElementResponse || (exports.CacheSortedSetRemoveElementResponse = {}));
var CacheSortedSetRemoveElementsResponse;
(function (CacheSortedSetRemoveElementsResponse) {
    CacheSortedSetRemoveElementsResponse["Success"] = "Success";
    CacheSortedSetRemoveElementsResponse["Error"] = "Error";
})(CacheSortedSetRemoveElementsResponse = exports.CacheSortedSetRemoveElementsResponse || (exports.CacheSortedSetRemoveElementsResponse = {}));
var CacheSortedSetUnionStoreResponse;
(function (CacheSortedSetUnionStoreResponse) {
    CacheSortedSetUnionStoreResponse["Success"] = "Success";
    CacheSortedSetUnionStoreResponse["Error"] = "Error";
})(CacheSortedSetUnionStoreResponse = exports.CacheSortedSetUnionStoreResponse || (exports.CacheSortedSetUnionStoreResponse = {}));
//# sourceMappingURL=data:application/json;base64,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