/**
 * Converts seconds to milliseconds.
 * @param seconds - The number of seconds to convert.
 * @returns The equivalent number of milliseconds.
 */
export declare function secondsToMilliseconds(seconds: number): number;
