export declare enum CacheSortedSetFetchResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheSortedSetGetRankResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheSortedSetGetScoreResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheSortedSetGetScoresResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheSortedSetIncrementScoreResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheSortedSetLengthResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheSortedSetLengthByScoreResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheSortedSetPutElementResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheSortedSetPutElementsResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheSortedSetRemoveElementResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheSortedSetRemoveElementsResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheSortedSetUnionStoreResponse {
    Success = "Success",
    Error = "Error"
}
