export declare enum StorageGetResponse {
    Found = "Found",
    NotFound = "NotFound",
    Error = "Error"
}
export declare enum StoragePutResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum StorageDeleteResponse {
    Success = "Success",
    Error = "Error"
}
