import { SdkError } from '../../errors';
import { SubscriptionRetryEligibilityStrategy } from './subscription-retry-eligibility-strategy';
export declare const DEFAULT_SUBSCRIPTION_RETRY_DELAY_MILLIS = 500;
export interface DetermineWhenToResubscribeProps {
    sdkError: SdkError;
}
export interface SubscriptionRetryStrategy {
    eligibilityStrategy: SubscriptionRetryEligibilityStrategy;
    retryDelayMillis: number;
    determineWhenToResubscribe(props: DetermineWhenToResubscribeProps): number | null;
}
