/**
 * Encapsulates a topic subscription stream state.
 */
export declare class SubscriptionState {
    private _unsubscribeFn;
    lastTopicSequenceNumber?: number;
    lastTopicSequencePage?: number;
    private _isSubscribed;
    constructor();
    get resumeAtTopicSequenceNumber(): number;
    get resumeAtTopicSequencePage(): number;
    setSubscribed(): void;
    setUnsubscribed(): void;
    get isSubscribed(): boolean;
    set unsubscribeFn(unsubscribeFn: () => void);
    unsubscribe(): void;
    toString(): string;
}
