export interface CacheLimits {
    maxTrafficRate: number;
    maxThroughputKbps: number;
    maxItemSizeKb: number;
    maxTtlSeconds: number;
}
export interface TopicLimits {
    maxPublishRate: number;
    maxSubscriptionCount: number;
    maxPublishMessageSizeKb: number;
}
export declare class CacheInfo {
    private readonly name;
    private readonly topicLimits;
    private readonly cacheLimits;
    constructor(name: string, topicLimits: TopicLimits, cacheLimits: CacheLimits);
    getName(): string;
    getTopicLimits(): TopicLimits;
    getCacheLimits(): CacheLimits;
}
