"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LeaderboardUpsertResponse = exports.LeaderboardRemoveElementsResponse = exports.LeaderboardLengthResponse = exports.LeaderboardFetchResponse = exports.LeaderboardDeleteResponse = void 0;
var LeaderboardDeleteResponse;
(function (LeaderboardDeleteResponse) {
    LeaderboardDeleteResponse["Success"] = "Success";
    LeaderboardDeleteResponse["Error"] = "Error";
})(LeaderboardDeleteResponse = exports.LeaderboardDeleteResponse || (exports.LeaderboardDeleteResponse = {}));
var LeaderboardFetchResponse;
(function (LeaderboardFetchResponse) {
    LeaderboardFetchResponse["Success"] = "Success";
    LeaderboardFetchResponse["Error"] = "Error";
})(LeaderboardFetchResponse = exports.LeaderboardFetchResponse || (exports.LeaderboardFetchResponse = {}));
var LeaderboardLengthResponse;
(function (LeaderboardLengthResponse) {
    LeaderboardLengthResponse["Success"] = "Success";
    LeaderboardLengthResponse["Error"] = "Error";
})(LeaderboardLengthResponse = exports.LeaderboardLengthResponse || (exports.LeaderboardLengthResponse = {}));
var LeaderboardRemoveElementsResponse;
(function (LeaderboardRemoveElementsResponse) {
    LeaderboardRemoveElementsResponse["Success"] = "Success";
    LeaderboardRemoveElementsResponse["Error"] = "Error";
})(LeaderboardRemoveElementsResponse = exports.LeaderboardRemoveElementsResponse || (exports.LeaderboardRemoveElementsResponse = {}));
var LeaderboardUpsertResponse;
(function (LeaderboardUpsertResponse) {
    LeaderboardUpsertResponse["Success"] = "Success";
    LeaderboardUpsertResponse["Error"] = "Error";
})(LeaderboardUpsertResponse = exports.LeaderboardUpsertResponse || (exports.LeaderboardUpsertResponse = {}));
//# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiaW5kZXguanMiLCJzb3VyY2VSb290IjoiIiwic291cmNlcyI6WyIuLi8uLi8uLi8uLi8uLi8uLi9zcmMvbWVzc2FnZXMvcmVzcG9uc2VzL2VudW1zL2xlYWRlcmJvYXJkL2luZGV4LnRzIl0sIm5hbWVzIjpbXSwibWFwcGluZ3MiOiI7OztBQUFBLElBQVkseUJBR1g7QUFIRCxXQUFZLHlCQUF5QjtJQUNuQyxnREFBbUIsQ0FBQTtJQUNuQiw0Q0FBZSxDQUFBO0FBQ2pCLENBQUMsRUFIVyx5QkFBeUIsR0FBekIsaUNBQXlCLEtBQXpCLGlDQUF5QixRQUdwQztBQUVELElBQVksd0JBR1g7QUFIRCxXQUFZLHdCQUF3QjtJQUNsQywrQ0FBbUIsQ0FBQTtJQUNuQiwyQ0FBZSxDQUFBO0FBQ2pCLENBQUMsRUFIVyx3QkFBd0IsR0FBeEIsZ0NBQXdCLEtBQXhCLGdDQUF3QixRQUduQztBQUVELElBQVkseUJBR1g7QUFIRCxXQUFZLHlCQUF5QjtJQUNuQyxnREFBbUIsQ0FBQTtJQUNuQiw0Q0FBZSxDQUFBO0FBQ2pCLENBQUMsRUFIVyx5QkFBeUIsR0FBekIsaUNBQXlCLEtBQXpCLGlDQUF5QixRQUdwQztBQUVELElBQVksaUNBR1g7QUFIRCxXQUFZLGlDQUFpQztJQUMzQyx3REFBbUIsQ0FBQTtJQUNuQixvREFBZSxDQUFBO0FBQ2pCLENBQUMsRUFIVyxpQ0FBaUMsR0FBakMseUNBQWlDLEtBQWpDLHlDQUFpQyxRQUc1QztBQUVELElBQVkseUJBR1g7QUFIRCxXQUFZLHlCQUF5QjtJQUNuQyxnREFBbUIsQ0FBQTtJQUNuQiw0Q0FBZSxDQUFBO0FBQ2pCLENBQUMsRUFIVyx5QkFBeUIsR0FBekIsaUNBQXlCLEtBQXpCLGlDQUF5QixRQUdwQyIsInNvdXJjZXNDb250ZW50IjpbImV4cG9ydCBlbnVtIExlYWRlcmJvYXJkRGVsZXRlUmVzcG9uc2Uge1xuICBTdWNjZXNzID0gJ1N1Y2Nlc3MnLFxuICBFcnJvciA9ICdFcnJvcicsXG59XG5cbmV4cG9ydCBlbnVtIExlYWRlcmJvYXJkRmV0Y2hSZXNwb25zZSB7XG4gIFN1Y2Nlc3MgPSAnU3VjY2VzcycsXG4gIEVycm9yID0gJ0Vycm9yJyxcbn1cblxuZXhwb3J0IGVudW0gTGVhZGVyYm9hcmRMZW5ndGhSZXNwb25zZSB7XG4gIFN1Y2Nlc3MgPSAnU3VjY2VzcycsXG4gIEVycm9yID0gJ0Vycm9yJyxcbn1cblxuZXhwb3J0IGVudW0gTGVhZGVyYm9hcmRSZW1vdmVFbGVtZW50c1Jlc3BvbnNlIHtcbiAgU3VjY2VzcyA9ICdTdWNjZXNzJyxcbiAgRXJyb3IgPSAnRXJyb3InLFxufVxuXG5leHBvcnQgZW51bSBMZWFkZXJib2FyZFVwc2VydFJlc3BvbnNlIHtcbiAgU3VjY2VzcyA9ICdTdWNjZXNzJyxcbiAgRXJyb3IgPSAnRXJyb3InLFxufVxuIl19