"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CacheSetLengthResponse = exports.CacheSetPopResponse = exports.CacheSetSampleResponse = exports.CacheSetRemoveElementsResponse = exports.CacheSetRemoveElementResponse = exports.CacheSetContainsElementsResponse = exports.CacheSetContainsElementResponse = exports.CacheSetFetchResponse = exports.CacheSetAddElementsResponse = exports.CacheSetAddElementResponse = void 0;
var CacheSetAddElementResponse;
(function (CacheSetAddElementResponse) {
    CacheSetAddElementResponse["Success"] = "Success";
    CacheSetAddElementResponse["Error"] = "Error";
})(CacheSetAddElementResponse = exports.CacheSetAddElementResponse || (exports.CacheSetAddElementResponse = {}));
var CacheSetAddElementsResponse;
(function (CacheSetAddElementsResponse) {
    CacheSetAddElementsResponse["Success"] = "Success";
    CacheSetAddElementsResponse["Error"] = "Error";
})(CacheSetAddElementsResponse = exports.CacheSetAddElementsResponse || (exports.CacheSetAddElementsResponse = {}));
var CacheSetFetchResponse;
(function (CacheSetFetchResponse) {
    CacheSetFetchResponse["Hit"] = "Hit";
    CacheSetFetchResponse["Miss"] = "Miss";
    CacheSetFetchResponse["Error"] = "Error";
})(CacheSetFetchResponse = exports.CacheSetFetchResponse || (exports.CacheSetFetchResponse = {}));
var CacheSetContainsElementResponse;
(function (CacheSetContainsElementResponse) {
    CacheSetContainsElementResponse["Hit"] = "Hit";
    CacheSetContainsElementResponse["Miss"] = "Miss";
    CacheSetContainsElementResponse["Error"] = "Error";
})(CacheSetContainsElementResponse = exports.CacheSetContainsElementResponse || (exports.CacheSetContainsElementResponse = {}));
var CacheSetContainsElementsResponse;
(function (CacheSetContainsElementsResponse) {
    CacheSetContainsElementsResponse["Hit"] = "Hit";
    CacheSetContainsElementsResponse["Miss"] = "Miss";
    CacheSetContainsElementsResponse["Error"] = "Error";
})(CacheSetContainsElementsResponse = exports.CacheSetContainsElementsResponse || (exports.CacheSetContainsElementsResponse = {}));
var CacheSetRemoveElementResponse;
(function (CacheSetRemoveElementResponse) {
    CacheSetRemoveElementResponse["Success"] = "Success";
    CacheSetRemoveElementResponse["Error"] = "Error";
})(CacheSetRemoveElementResponse = exports.CacheSetRemoveElementResponse || (exports.CacheSetRemoveElementResponse = {}));
var CacheSetRemoveElementsResponse;
(function (CacheSetRemoveElementsResponse) {
    CacheSetRemoveElementsResponse["Success"] = "Success";
    CacheSetRemoveElementsResponse["Error"] = "Error";
})(CacheSetRemoveElementsResponse = exports.CacheSetRemoveElementsResponse || (exports.CacheSetRemoveElementsResponse = {}));
var CacheSetSampleResponse;
(function (CacheSetSampleResponse) {
    CacheSetSampleResponse["Hit"] = "Hit";
    CacheSetSampleResponse["Miss"] = "Miss";
    CacheSetSampleResponse["Error"] = "Error";
})(CacheSetSampleResponse = exports.CacheSetSampleResponse || (exports.CacheSetSampleResponse = {}));
var CacheSetPopResponse;
(function (CacheSetPopResponse) {
    CacheSetPopResponse["Hit"] = "Hit";
    CacheSetPopResponse["Miss"] = "Miss";
    CacheSetPopResponse["Error"] = "Error";
})(CacheSetPopResponse = exports.CacheSetPopResponse || (exports.CacheSetPopResponse = {}));
var CacheSetLengthResponse;
(function (CacheSetLengthResponse) {
    CacheSetLengthResponse["Hit"] = "Hit";
    CacheSetLengthResponse["Miss"] = "Miss";
    CacheSetLengthResponse["Error"] = "Error";
})(CacheSetLengthResponse = exports.CacheSetLengthResponse || (exports.CacheSetLengthResponse = {}));
//# sourceMappingURL=data:application/json;base64,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