export declare enum CacheGetResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheSetResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheDeleteResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheIncrementResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheGetBatchResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheSetBatchResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheSetIfAbsentResponse {
    Stored = "Stored",
    NotStored = "NotStored",
    Error = "Error"
}
export declare enum CacheSetIfPresentResponse {
    Stored = "Stored",
    NotStored = "NotStored",
    Error = "Error"
}
export declare enum CacheSetIfEqualResponse {
    Stored = "Stored",
    NotStored = "NotStored",
    Error = "Error"
}
export declare enum CacheSetIfNotEqualResponse {
    Stored = "Stored",
    NotStored = "NotStored",
    Error = "Error"
}
export declare enum CacheSetIfAbsentOrEqualResponse {
    Stored = "Stored",
    NotStored = "NotStored",
    Error = "Error"
}
export declare enum CacheSetIfPresentAndNotEqualResponse {
    Stored = "Stored",
    NotStored = "NotStored",
    Error = "Error"
}
export declare enum CacheSetIfNotExistsResponse {
    Stored = "Stored",
    NotStored = "NotStored",
    Error = "Error"
}
export declare enum CacheKeyExistsResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheKeysExistResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheItemGetTypeResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheItemGetTtlResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheUpdateTtlResponse {
    Set = "Set",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheIncreaseTtlResponse {
    Set = "Set",
    NotSet = "NotSet",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheDecreaseTtlResponse {
    Set = "Set",
    NotSet = "NotSet",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheGetWithHashResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheSetWithHashResponse {
    Stored = "Stored",
    NotStored = "NotStored",
    Error = "Error"
}
export declare enum CacheSetIfPresentAndHashEqualResponse {
    Stored = "Stored",
    NotStored = "NotStored",
    Error = "Error"
}
export declare enum CacheSetIfPresentAndHashNotEqualResponse {
    Stored = "Stored",
    NotStored = "NotStored",
    Error = "Error"
}
export declare enum CacheSetIfAbsentOrHashEqualResponse {
    Stored = "Stored",
    NotStored = "NotStored",
    Error = "Error"
}
export declare enum CacheSetIfAbsentOrHashNotEqualResponse {
    Stored = "Stored",
    NotStored = "NotStored",
    Error = "Error"
}
