import { SdkError } from '../../errors';
import { BaseResponseError, BaseResponseSuccess } from './response-base';
import { CacheSortedSetUnionStoreResponse } from './enums';
interface IResponse {
    readonly type: CacheSortedSetUnionStoreResponse;
}
/**
 * Indicates a Successful sorted set union store request.
 */
export declare class Success extends BaseResponseSuccess implements IResponse {
    readonly type: CacheSortedSetUnionStoreResponse.Success;
    private readonly _length;
    constructor(length: number);
    /**
     * Returns the length of the sorted set
     * @returns {number}
     */
    length(): number;
    toString(): string;
}
export declare class Error extends BaseResponseError implements IResponse {
    readonly type: CacheSortedSetUnionStoreResponse.Error;
    constructor(error: SdkError);
}
export type Response = Success | Error;
export {};
