"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CacheDictionarySetFieldsResponse = exports.CacheDictionarySetFieldResponse = exports.CacheDictionaryRemoveFieldsResponse = exports.CacheDictionaryRemoveFieldResponse = exports.CacheDictionaryLengthResponse = exports.CacheDictionaryIncrementResponse = exports.CacheDictionaryFetchResponse = exports.CacheDictionaryGetFieldResponse = exports.CacheDictionaryGetFieldsResponse = void 0;
var CacheDictionaryGetFieldsResponse;
(function (CacheDictionaryGetFieldsResponse) {
    CacheDictionaryGetFieldsResponse["Hit"] = "Hit";
    CacheDictionaryGetFieldsResponse["Miss"] = "Miss";
    CacheDictionaryGetFieldsResponse["Error"] = "Error";
})(CacheDictionaryGetFieldsResponse = exports.CacheDictionaryGetFieldsResponse || (exports.CacheDictionaryGetFieldsResponse = {}));
var CacheDictionaryGetFieldResponse;
(function (CacheDictionaryGetFieldResponse) {
    CacheDictionaryGetFieldResponse["Hit"] = "Hit";
    CacheDictionaryGetFieldResponse["Miss"] = "Miss";
    CacheDictionaryGetFieldResponse["Error"] = "Error";
})(CacheDictionaryGetFieldResponse = exports.CacheDictionaryGetFieldResponse || (exports.CacheDictionaryGetFieldResponse = {}));
var CacheDictionaryFetchResponse;
(function (CacheDictionaryFetchResponse) {
    CacheDictionaryFetchResponse["Hit"] = "Hit";
    CacheDictionaryFetchResponse["Miss"] = "Miss";
    CacheDictionaryFetchResponse["Error"] = "Error";
})(CacheDictionaryFetchResponse = exports.CacheDictionaryFetchResponse || (exports.CacheDictionaryFetchResponse = {}));
var CacheDictionaryIncrementResponse;
(function (CacheDictionaryIncrementResponse) {
    CacheDictionaryIncrementResponse["Success"] = "Success";
    CacheDictionaryIncrementResponse["Error"] = "Error";
})(CacheDictionaryIncrementResponse = exports.CacheDictionaryIncrementResponse || (exports.CacheDictionaryIncrementResponse = {}));
var CacheDictionaryLengthResponse;
(function (CacheDictionaryLengthResponse) {
    CacheDictionaryLengthResponse["Hit"] = "Hit";
    CacheDictionaryLengthResponse["Miss"] = "Miss";
    CacheDictionaryLengthResponse["Error"] = "Error";
})(CacheDictionaryLengthResponse = exports.CacheDictionaryLengthResponse || (exports.CacheDictionaryLengthResponse = {}));
var CacheDictionaryRemoveFieldResponse;
(function (CacheDictionaryRemoveFieldResponse) {
    CacheDictionaryRemoveFieldResponse["Success"] = "Success";
    CacheDictionaryRemoveFieldResponse["Error"] = "Error";
})(CacheDictionaryRemoveFieldResponse = exports.CacheDictionaryRemoveFieldResponse || (exports.CacheDictionaryRemoveFieldResponse = {}));
var CacheDictionaryRemoveFieldsResponse;
(function (CacheDictionaryRemoveFieldsResponse) {
    CacheDictionaryRemoveFieldsResponse["Success"] = "Success";
    CacheDictionaryRemoveFieldsResponse["Error"] = "Error";
})(CacheDictionaryRemoveFieldsResponse = exports.CacheDictionaryRemoveFieldsResponse || (exports.CacheDictionaryRemoveFieldsResponse = {}));
var CacheDictionarySetFieldResponse;
(function (CacheDictionarySetFieldResponse) {
    CacheDictionarySetFieldResponse["Success"] = "Success";
    CacheDictionarySetFieldResponse["Error"] = "Error";
})(CacheDictionarySetFieldResponse = exports.CacheDictionarySetFieldResponse || (exports.CacheDictionarySetFieldResponse = {}));
var CacheDictionarySetFieldsResponse;
(function (CacheDictionarySetFieldsResponse) {
    CacheDictionarySetFieldsResponse["Success"] = "Success";
    CacheDictionarySetFieldsResponse["Error"] = "Error";
})(CacheDictionarySetFieldsResponse = exports.CacheDictionarySetFieldsResponse || (exports.CacheDictionarySetFieldsResponse = {}));
//# sourceMappingURL=data:application/json;base64,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