"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CacheListPopFrontResponse = exports.CacheListPopBackResponse = exports.CacheListLengthResponse = exports.CacheListFetchResponse = exports.CacheListRetainResponse = exports.CacheListRemoveValueResponse = exports.CacheListPushFrontResponse = exports.CacheListPushBackResponse = exports.CacheListConcatenateFrontResponse = exports.CacheListConcatenateBackResponse = void 0;
var CacheListConcatenateBackResponse;
(function (CacheListConcatenateBackResponse) {
    CacheListConcatenateBackResponse["Success"] = "Success";
    CacheListConcatenateBackResponse["Error"] = "Error";
})(CacheListConcatenateBackResponse = exports.CacheListConcatenateBackResponse || (exports.CacheListConcatenateBackResponse = {}));
var CacheListConcatenateFrontResponse;
(function (CacheListConcatenateFrontResponse) {
    CacheListConcatenateFrontResponse["Success"] = "Success";
    CacheListConcatenateFrontResponse["Error"] = "Error";
})(CacheListConcatenateFrontResponse = exports.CacheListConcatenateFrontResponse || (exports.CacheListConcatenateFrontResponse = {}));
var CacheListPushBackResponse;
(function (CacheListPushBackResponse) {
    CacheListPushBackResponse["Success"] = "Success";
    CacheListPushBackResponse["Error"] = "Error";
})(CacheListPushBackResponse = exports.CacheListPushBackResponse || (exports.CacheListPushBackResponse = {}));
var CacheListPushFrontResponse;
(function (CacheListPushFrontResponse) {
    CacheListPushFrontResponse["Success"] = "Success";
    CacheListPushFrontResponse["Error"] = "Error";
})(CacheListPushFrontResponse = exports.CacheListPushFrontResponse || (exports.CacheListPushFrontResponse = {}));
var CacheListRemoveValueResponse;
(function (CacheListRemoveValueResponse) {
    CacheListRemoveValueResponse["Success"] = "Success";
    CacheListRemoveValueResponse["Error"] = "Error";
})(CacheListRemoveValueResponse = exports.CacheListRemoveValueResponse || (exports.CacheListRemoveValueResponse = {}));
var CacheListRetainResponse;
(function (CacheListRetainResponse) {
    CacheListRetainResponse["Success"] = "Success";
    CacheListRetainResponse["Error"] = "Error";
})(CacheListRetainResponse = exports.CacheListRetainResponse || (exports.CacheListRetainResponse = {}));
var CacheListFetchResponse;
(function (CacheListFetchResponse) {
    CacheListFetchResponse["Hit"] = "Hit";
    CacheListFetchResponse["Miss"] = "Miss";
    CacheListFetchResponse["Error"] = "Error";
})(CacheListFetchResponse = exports.CacheListFetchResponse || (exports.CacheListFetchResponse = {}));
var CacheListLengthResponse;
(function (CacheListLengthResponse) {
    CacheListLengthResponse["Hit"] = "Hit";
    CacheListLengthResponse["Miss"] = "Miss";
    CacheListLengthResponse["Error"] = "Error";
})(CacheListLengthResponse = exports.CacheListLengthResponse || (exports.CacheListLengthResponse = {}));
var CacheListPopBackResponse;
(function (CacheListPopBackResponse) {
    CacheListPopBackResponse["Hit"] = "Hit";
    CacheListPopBackResponse["Miss"] = "Miss";
    CacheListPopBackResponse["Error"] = "Error";
})(CacheListPopBackResponse = exports.CacheListPopBackResponse || (exports.CacheListPopBackResponse = {}));
var CacheListPopFrontResponse;
(function (CacheListPopFrontResponse) {
    CacheListPopFrontResponse["Hit"] = "Hit";
    CacheListPopFrontResponse["Miss"] = "Miss";
    CacheListPopFrontResponse["Error"] = "Error";
})(CacheListPopFrontResponse = exports.CacheListPopFrontResponse || (exports.CacheListPopFrontResponse = {}));
//# sourceMappingURL=data:application/json;base64,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