export declare enum WebhookDestinationType {
    PostUrl = "post_url"
}
interface IPostUrlWebhookDestination {
    url: () => string;
    type: WebhookDestinationType.PostUrl;
    getType: () => WebhookDestinationType.PostUrl;
}
export declare class PostUrlWebhookDestination implements IPostUrlWebhookDestination {
    readonly _url: string;
    constructor(url: string);
    url(): string;
    type: WebhookDestinationType.PostUrl;
    getType(): WebhookDestinationType.PostUrl;
}
export type WebhookDestination = InstanceType<typeof PostUrlWebhookDestination>;
export {};
