export declare enum CreateCacheResponse {
    Success = "Success",
    AlreadyExists = "AlreadyExists",
    Error = "Error"
}
export declare enum DeleteCacheResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum FlushCacheResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum ListCachesResponse {
    Success = "Success",
    Error = "Error"
}
