export declare enum PutWebhookResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum DeleteWebhookResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum RotateWebhookSecretResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum GetWebhookSecretResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum ListWebhooksResponse {
    Success = "Success",
    Error = "Error"
}
