export declare enum LeaderboardDeleteResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum LeaderboardFetchResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum LeaderboardLengthResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum LeaderboardRemoveElementsResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum LeaderboardUpsertResponse {
    Success = "Success",
    Error = "Error"
}
