import { ExpiresIn, SortedSetSource } from '../../utils';
export declare function validateStoreName(name: string): void;
export declare function validateCacheName(name: string): void;
export declare function validateCacheKeyOrPrefix(name: string): void;
export declare function validateSetName(name: string): void;
export declare function validateSetSampleLimit(limit: number): void;
export declare function validateSetPopCount(count: number): void;
export declare function validateSortedSetName(name: string): void;
export declare function validateSortedSetRanks(start_rank: number, end_rank?: number): void;
export declare function validateSortedSetScores(minScore?: number, maxScore?: number): void;
export declare function validateSortedSetOffset(offset: number): void;
export declare function validateSortedSetCount(count: number): void;
export declare function validateDictionaryName(name: string): void;
export declare function validateListName(name: string): void;
export declare function validateListSliceStartEnd(startIndex?: number, endIndex?: number): void;
export declare function validateTopicName(name: string): void;
export declare function validateWebhookName(name: string): void;
export declare function validateIndexName(name: string): void;
export declare function validateNumDimensions(numDimensions: number): void;
export declare function validateTopK(topK: number): void;
export declare function validateTtlMinutes(ttlMinutes: number): void;
export declare function validateTtlSeconds(ttl: number): void;
export declare function validateValidForSeconds(validForSeconds: number): void;
export declare function validateTimeout(timeout: number): void;
export declare function validateDisposableTokenExpiry(expiresIn: ExpiresIn): void;
export declare function validateDisposableTokenTokenID(tokenId: string): void;
export declare function isBase64(str: string): boolean;
export declare function validateLeaderboardName(name: string): void;
export declare function validateLeaderboardRanks(start_rank: number, end_rank: number): void;
export declare function validateLeaderboardOffset(offset: number): void;
export declare function validateLeaderboardCount(count: number): void;
export declare function validateLeaderboardNumberOfElements(numElements: number): void;
export declare function validateMaxConcurrentRequests(limit: number): void;
export declare function validateSortedSetSources(sources: SortedSetSource[]): void;
