export declare enum CreateStoreResponse {
    Success = "Success",
    AlreadyExists = "AlreadyExists",
    Error = "Error"
}
export declare enum ListStoresResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum DeleteStoreResponse {
    Success = "Success",
    Error = "Error"
}
