export declare enum CacheSetAddElementResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheSetAddElementsResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheSetFetchResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheSetContainsElementResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheSetContainsElementsResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheSetRemoveElementResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheSetRemoveElementsResponse {
    Success = "Success",
    Error = "Error"
}
export declare enum CacheSetSampleResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheSetPopResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
export declare enum CacheSetLengthResponse {
    Hit = "Hit",
    Miss = "Miss",
    Error = "Error"
}
