import { MomentoLogger, MomentoLoggerFactory } from './momento-logger';
export declare class NoopMomentoLogger implements MomentoLogger {
    debug(msg: string, ...args: unknown[]): void;
    error(msg: string, ...args: unknown[]): void;
    info(msg: string, ...args: unknown[]): void;
    trace(msg: string, ...args: unknown[]): void;
    warn(msg: string, ...args: unknown[]): void;
}
export declare class NoopMomentoLoggerFactory implements MomentoLoggerFactory {
    getLogger(loggerName: string | any): MomentoLogger;
}
