export declare class Semaphore {
    private counter;
    private waiting;
    private max;
    constructor(max: number);
    take(): void;
    acquire(): Promise<unknown>;
    release(): void;
    purge(): number;
}
